@@ -78,7 +78,7 @@ pub fn parse_gateway_event(
         .deserialize(&mut json_deserializer)
         .map_err(|source| {
             #[cfg(feature = "tracing")]
-            tracing::debug!("invalid JSON: {}", String::from_utf8_lossy(json));
+            tracing::error!("invalid JSON: {}", String::from_utf8_lossy(json));
 
             GatewayEventParsingError {
                 kind: GatewayEventParsingErrorType::Deserializing,
@@ -120,7 +120,7 @@ pub fn parse_gateway_event(
         .deserialize(&mut json_deserializer)
         .map_err(|source| {
             #[cfg(feature = "tracing")]
-            tracing::debug!("invalid JSON: {}", String::from_utf8_lossy(json));
+            tracing::error!("invalid JSON: {}", String::from_utf8_lossy(json));
 
             GatewayEventParsingError {
                 kind: GatewayEventParsingErrorType::Deserializing,
