@@ -415,7 +415,7 @@ impl ShardProcessor {
                         source,
                     );
                 } else {
-                    tracing::warn!(
+                    tracing::error!(
                         shard_id = self.config.shard()[0],
                         shard_total = self.config.shard()[1],
                         "processing incoming event failed: {:?}",
@@ -460,7 +460,7 @@ impl ShardProcessor {
                     (op, seq, event_type.map(ToOwned::to_owned))
                 } else {
                     #[cfg(feature = "tracing")]
-                    tracing::warn!(
+                    tracing::error!(
                         json = ?self.compression.buffer_slice_mut(),
                         shard_id = self.config.shard()[0],
                         shard_total = self.config.shard()[1],
